* Get ready
clear all
pause on
set more off



*******************
*** START *********
*******************

use "temp/aux3_largest_do_vege_print.dta", clear



*************************
*** Create the graphs ***
*************************


*** Figure 1: Advertising and circulation shares in right wing daily relative to left and right wing daily

preserve

keep if year<2015
replace media="MAGYAR NEMZET" if media=="NAPI MAGYARORSZÁG"
keep if media=="NÉPSZABADSÁG"|media=="MAGYAR NEMZET"
replace type=1 if type==2

gen year_calendar=year
forvalues i = 1994/2015  {
	replace year=`i' if year_calendar==`i'&month>=6|year_calendar==`i'+1&month<6
}

collapse (sum) spending ,by(year media type)
set obs `=_N+1'
replace year=2016 if year==.
replace media="MAGYAR NEMZET" if media==""

egen spending_all=sum(spending), by(year type)
gen spending_share=spending/spending_all*100

merge m:1 media year using "input/circulation/circulation_16_yearly.dta"

rename totalspread circ
egen circ_all=sum(circ), by(year type)
gen circ_share=circ/circ_all*100

gen year2=year+0.4
local max=100
gen orban1=`max' if year>=1998&year<=2002&media=="MAGYAR NEMZET" 
gen orban2=`max' if year>=2010&media=="MAGYAR NEMZET" 

twoway area orban1 year, bcolor(gs14) || ///
	   area orban2 year, bcolor(gs14) || ///
       connected spending_share year2 if media=="MAGYAR NEMZET"&type==1, sort(year) mcolor(blue) lcolor(blue) msymbol(d) || ///
	   connected spending_share year2 if media=="MAGYAR NEMZET"&type==3, sort(year) mcolor(red) lcolor(red) msymbol(O) || ///
	   connected circ_share year2 if media=="MAGYAR NEMZET"&type==1&year>=2000, sort(year) mcolor(black) lcolor(black) msymbol(T) ///
			legend( label(3 Private firms' advertising) label(4 State-owned firms' advertising) label(5 Circulation)) legend(order(3 4 5))  ///
			xtitle("Year") ytitle("%") /*title("Top Two Political Newspapers, R/(L+R)")*/ ///
			xlabel( 1994.4 "1994" 1998.4 "1998" 2002.4 "2002" 2006.4 "2006"  2010.4 "2010"  2014.4 "2014") graphregion(color(white)) plotregion(m(tiny)) ///
			note("Shaded areas represent right-wing governments.")

graph export "output/figure1.pdf", as(pdf) replace

restore



*** Figure X: Fallout in daily newspaper market

preserve

replace type=1 if type==2

collapse (sum) spending, by(year month media type)
merge m:1 media year month using "input/circulation/circulation_16.dta", keep(1 3) nogen

gen media_color="independent"
replace media_color="right" if media=="MAGYAR NEMZET"| strpos(media,"METROPOL")

collapse (sum) spending circulation=totalspread , by(year month media_color type)
fillin year month media_color type
keep if year >= 2006
drop if year == 2016 & month > 5

foreach X in spending circulation{
	replace `X' = 0 if missing(`X')
	egen `X'_tot = total(`X'), by(year month type)
	gen `X'_share = `X'/`X'_tot*100
}
replace circulation_share=. if year > 2015

egen time=group(year month)

sum time if year == 2010 & month == 6
local election = `r(mean)'

sum time if year == 2015 & month == 2
local fallout = `r(mean)'


twoway connected spending_share time if media_color=="right"    & type==1 & year>=2006, sort(time) mcolor(blue) lcolor(blue) msymbol(d)|| ///
	   connected spending_share time if media_color=="right"    & type==3 & year>=2006, sort(time) mcolor(red) lcolor(red) msymbol(O) || ///
	   connected circulation_share time if media_color=="right" & type==1 & year>=2006, sort(time) mcolor(black) lcolor(black) lpattern(solid) msymbol(T) ///
			xlabel( 141 "2006" 165 "2008" 189 "2010" 213 "2012"  237 "2014") ///
			xtitle("") legend(label(1 Private firms' advertising) label(2 State-owned firms' advertising) ///
			label(3 Circulation)) graphregion(color(white)) plotregion(m(tiny)) ///
			ytitle("%") /*title("Daily Newspapers, R/All")*/ xli(`election' `fallout', lwidth(thick) lcolor("green")) ///
			xla(`election' "right wins 2010 election" `fallout' "fallout in 2015") 

graph export "output/figure3.pdf", as(pdf) replace

restore



*** Figure 2a: Event study I: Advertising share of Metropol around purchase by right-wing investor
preserve

replace type=1 if type==2
keep if year < 2015
gen day=1
gen edate = mdy(month, day, year)

collapse (sum) spending (first) edate, by(year month media type)
egen spending_all=sum(spending), by(year month type)
gen spending_share=spending/spending_all*100

merge m:1 media year month using "input/circulation/circulation.dta"

rename totalspread circulation
egen circulation_all=sum(circulation), by(year month type)
gen circulation_share=circulation/circulation_all*100

local max=60
gen orban=`max' if edate>=18414&media=="METROPOL" 

twoway area orban edate if media=="METROPOL"&type==1 &year>=2006, bcolor(gs14) || ///
	   pci 0 18809 60 18809, lcolor("green") lwidth("thick") || ///
	   connected spending_share edate if media=="METROPOL"&type==1 &year>=2006, sort(edate) mcolor(blue) lcolor(blue) msymbol(d)|| ///
	   connected spending_share edate if media=="METROPOL"&type==3&year>=2006, sort(edate) mcolor(red) lcolor(red) msymbol(O) || ///
	   connected circulation_share edate if media=="METROPOL"&type==1&year>=2006, sort(edate) mcolor(black) lcolor(black) lpattern(solid) msymbol(T) ///
			xlabel( /*16983 "July 2006"*/ 17714 "July 2008" /*18414 "Gov change"*/ 18809 "Metropol purchase" 19905 "July 2014") ///
			legend(label(3 Private firms' advertising) label(4 State-owned firms' advertising) label(5 Circulation)) legend(order(3 4 5)) ///
			graphregion(color(white)) plotregion(m(tiny)) note("Shaded areas represent right-wing governments.") yscale(range(0 60)) ///
			xtitle("") ytitle("%") /*title("Daily Newspapers, Metropol/All")*/

graph export "output/figure2.pdf", as(pdf) replace

