clear all
pause on
set more off


*******************
*** START *********
*******************


use "temp/aux3_largest_do_vege_online.dta", clear

replace media="index" if strpos(media,"CEMP")
replace media="origo" if strpos(media,"ORIGO")
replace media="24.hu" if strpos(media,"CENTRAL MÉDIACSOPORT")
replace media="hvg" if strpos(media,"HVG")
replace media="ringier" if strpos(media,"RINGIER")|strpos(media,"AXEL SPRINGER")

keep if media=="index" | media=="origo" /*| media=="24.hu" */

gen media_color = "independent"
replace media_color="right" if media=="origo"


***** Origo share figure ******
preserve

replace type=1 if type==2

gen day=1
gen edate = mdy(month, day, year)
format edate %td

gen quarter = 1 if month==1|month==2|month==3
replace quarter = 2 if month==4|month==5|month==6
replace quarter = 3 if month==7|month==8|month==9
replace quarter = 4 if month==10|month==11|month==12

collapse (sum) spending surface (first) edate media_color, by(year quarter media type)
egen spending_all=sum(spending), by(year quarter type)
gen spending_share=spending/spending_all*100

egen surface_all=sum(surface), by(year quarter type)
gen surface_share=surface/surface_all*100

tempfile online
save `online', replace

import delimited "temp/news-outlets-reader-count-pc-adjusted-quarterly-sum.csv", clear
keep if media=="index" | media=="origo"

by year quarter, sort: egen qsum_visitor = total(visitor)
gen visitor_share = visitor/qsum_visitor*100
merge 1:m year quarter media using `online', nogenerate

sort edate
egen time=group(year quarter)
twoway connected spending_share time if media=="origo"&type==1 &year>=2013, sort(time) mcolor(blue) lcolor(blue) msymbol(d)|| ///
	   connected spending_share time if media=="origo"&type==3&year>=2013, sort(time) mcolor(red) lcolor(red) msymbol(O) || ///
	   connected visitor_share time if media=="origo"&type==3&year>=2013, sort(time) mcolor(black) lcolor(black) msymbol(t) ///
			xtitle("") legend(label(1 "Private firms' advertising") label(2 "State-owned firms' advertising") label(3 "Visitors")) /// 
			graphregion(color(white)) plotregion(m(tiny)) ///
			ytitle("%") /*title("Advertising share of Origo, Origo/(Index+Origo)")*/ xli(39 45, lwidth(thick) lcolor("green")) ///
			xlabel(33 "2013" 39 "change of editor" 45 "change of owner" 48 "2017") xmtick(33 48) 

graph export "output/figure4.pdf", as(pdf) replace







