
* - Identifies government agencies  and local governments (name based matches/use of pir-ids)
* - Defines mutually exclusive ownership categories

* tax_ids are fixed: real taxids are positive, proxies are negative, for those not fitting any category, and no tax_id found replaced with . and dropped
* optional categorization for government agencies based on string search is included


*******************
*** START *********
*******************

use "temp/aux1_import_do_end.dta", clear



*******************************************************************************
* GENERATE LOCAL GOV, GOVT AGENCY VARS, FILL IN
*******************************************************************************	


*** Local Governments
drop if advertiser=="ÖNKORMÁNYZATI MINISZTÉRIUM" ///
	 | advertiser=="ÖNKORMÁNYZATOK" ///
	 | advertiser=="TELEPÜLÉSI ÖNKORM.ORSZ.SZÖV." ///
	 | strpos(advertiser, "BIZTOSÍTÁSI ÖNKORM.") ///
	 | strpos(advertiser, "KISEBBSÉGI ÖNKORM") ///
	 | strpos(advertiser, "ÖNKORMÁNYZATI") ///
	 | advertiser=="EGYÉB HIRDETŐ" ///
	 | (strpos(advertiser, "ORSZÁGOS") & strpos(advertiser, "ÖNKORM"))

gen localgov_name = strpos(advertiser, "ÖNKORMÁNYZA") ///
					| strpos(advertiser, "ÖNKORM.")

egen localgov = max(localgov_name), by(tax_idadvertiser)	
tab advertiser if localgov==1
tab advertiser if localgov != localgov_name, m	
drop localgov_name


*** Government Agencies
* - there is pir id & no tax_id
* - taxid starts with 15 16
* - ministries

drop if advertiser=="ÁSVÁNYOLAJTERMÉK MIN.ELL.RT." ///
		| strpos(advertiser, "IDEGENFORGALMI HIVATAL")

gen govt_agency_name = (tax_idad<0 & pir!=. & localgov!=1 & pol!=1) ///
	| (strpos(advertiser, "MINISZTÉRIUM") ///
	| strpos(advertiser, " MIN.") ///
	| strpos(advertiser, "GAZD.MIN.") ///
	| advertiser=="INFORMATIKAI ÉS HÍRKÖZLÉSI MIN" ///
	| advertiser=="MAGYAR NEMZETI BANK"	///
	| strpos(advertiser, "FELÜGY") ///
	| strpos(advertiser, "FGY") ///
	| strpos(advertiser, "IGAZGATÓSÁG") ///
	| strpos(advertiser, " IG.") ///
	| strpos(advertiser, "HIVATAL") ///
	| strpos(advertiser, "HIV.") ///
	| strpos(advertiser,"ÁLLAMI") ///
	| strpos(advertiser, "EGYETEM") ///
	| strpos(advertiser, "FŐISK") ///
	| strpos(advertiser,"FI.") ///
	| strpos(advertiser, "KÖZOKTATÁS") ///
	| strpos(advertiser, "LEVÉLTÁR") ///
	| strpos(advertiser, "KÖNYVTÁR") ///
	| strpos(advertiser, "MAGYAR TUDOMÁNYOS AKADÉMIA") ///
	| advertiser=="ZENEAKADÉMIA BUDAPEST" ///
	| advertiser=="MAGYAR MÉDIA AKADÉMIA" ///
	| advertiser=="NEMZETI KULTURÁLIS ALAP" ///
	| advertiser=="MAGYAR NEMZETI FILMARCHÍVUM" ///
	| advertiser=="FELVÉTELI INFORMÁCIÓS SZOLG." ///
	| advertiser=="NEMZETI ÚTDÍJFIZ.SZOLG.ZRT." ///
	| advertiser=="ORSZÁGOS RENDŐRFŐKAPITÁNYSÁG" ///
	| advertiser=="ORSZ.BÜNTETÉS-VÉGREHAJTÁSI INT" ///
	| advertiser=="KÖZBESZERZÉSEK TANÁCSA" ///
	| strpos(advertiser, "FEJLESZTÉSI TANÁCS") ///
	| strpos(advertiser, "FEJLESZTÉSI INTÉZET") ///
	| advertiser=="FELVÉTELI INFORMÁCIÓS SZOLG" ///
	| strpos(advertiser, " KÓRHÁZ") ///
	| (strpos(advertiser, "ORSZ") & strpos(advertiser, "INTÉZET")) ///
	| advertiser=="ÁLL.NÉPEÜI.TISZTIORVOSI SZOLG." ///
	| strpos(advertiser, ".EGÉSZSÉGBIZT.PÉNZT") ///
	| strpos(advertiser, "EGÉSZSÉGÜGYI") ///
	| (strpos(advertiser, "ORSZ") & strpos(advertiser, "KÖZP")) ///
	| strpos(advertiser, "NEMZETI PARK") ///
	| advertiser=="NEMZETI ÖRÖKSÉG INTÉZETE" ///
	| advertiser=="NEMZ.FENNTARTHATÓ FEJL.TANÁCS"	///
	| advertiser=="MUNKAERŐFEJLESZTÉSI KÖZPONT"  ///
	| advertiser=="ORSZ.FOGLALKOZTATÁSI ALAP." ///
	| advertiser=="ORSZ.MŰSZAKI FEJLESZTÉSI BIZ." ///
	| advertiser=="NEMZETI CSALÁD-ÉS SZOC.POL.INT" ///
	| advertiser=="TERÜLETFEJLESZTÉSI TANÁCS" ///
	| advertiser=="MAGYAR KÖZIGAZGATÁSI INTÉZET" ///
	| advertiser=="ORSZ.ÉLELM.TÁPLÁLKOZÁSTUD.INT." ///
	| strpos(advertiser,"MAGYAR FEJLESZTÉSI") ///
	| advertiser=="MAGYAR NEMZETI BANK" ///
	| advertiser=="REGIONÁLIS FEJLESZTÉSI TANÁCS" ///
	| advertiser=="KINCSTÁRI VAGYONKEZELŐ SZERV." ///
	| advertiser=="MAGYAR ÁLLAMKINCSTÁR" ///
	| advertiser=="REGIONÁLIS VÁLLALK.FEJL.ALAP." ///
	| strpos(advertiser, "MŰV.HÁZ") ///
	| strpos(advertiser, "SZÍNHÁZ") ///
	| strpos(advertiser, "MÚZEUM") ///
	| strpos(advertiser, "NEMZ.") ///
	| strpos(advertiser, "GYÓGYFÜRDŐ") ///
	| advertiser=="NEMZETI CIVIL ALAPPROGRAM" ///
	| advertiser=="MAGYAR HIVATALOS KÖZLÖNYKIADÓ") 
replace govt_agency_name = 0 if tax_idadvertiser == 11946092 /*KLUBSZÍNHÁZ, AVENTURA MÉDIA KFT.*/

egen govt_agency = max(govt_agency_name), by(tax_idadvertiser)	
tab advertiser if govt_agency != govt_agency_name, m	
drop govt_agency_name
*
	
	
*** Fill in ownership statuses
foreach i of varlist ?o3 {
	replace `i'=0 if govt_agency==1 | localgov==1
}
gen check=do3+fo3+so3+mo3+localgov+govt_agency
tab check, miss
count if check>=2 & !missing(check)
assert r(N) == 0
drop check



*** Drop unknown firms
replace tax_idadvertiser=. if ///
		tax_idadvertiser<0 & localgov==0 & govt_agency==0 & pol_party==0 & so3==.
drop if	tax_idadvertiser==.


	
********************************************************************************
*  CLASSIFY GOVERNMENT AGENCIES BASED ON FUNCTION
********************************************************************************

gen ministry=.
replace ministry=0 if govt_agency==1
replace ministry=1 if govt_agency==1   ///
		& (strpos(advertiser,"MINISZTÉRIUM") |  strpos(advertiser,"MIN.") ///
		|  strpos(advertiser,"MINISZT"))

gen education=.
replace education=0 if govt_agency==1
replace education=1 if govt_agency==1  & ministry!=1 ///
										& (strpos(advertiser, "ISKOLA") ///
										| strpos(advertiser, "EGYETEM") ///
										| strpos(advertiser, "OKTATÁSI") ///
										| strpos(advertiser, "TANÁR") ///
										| strpos(advertiser, "FŐISK") ///
										| strpos(advertiser, "FI.") ///
										| strpos(advertiser, "PEDAGÓGIA")) 

gen culture=.
replace culture=0 if govt_agency==1
replace culture=1 if govt_agency==1   & ministry!=1 & education!=1 ///
										& (strpos(advertiser, "SZÍNHÁZ") ///
										| strpos(advertiser, "MÚZEUM") ///
										| strpos(advertiser, "GALÉRIA") ///
										| strpos(advertiser, "ZENEKAR") ///
										| strpos(advertiser, "OPERA") ///
										| strpos(advertiser, "BALETT") ///
										| strpos(advertiser, "KÖNYVTÁR") ///
										| strpos(advertiser, "TELEVÍZIÓ") ///
										| strpos(advertiser, "RÁDIÓ") ///
										| strpos(advertiser, "TELEVÍZIÓ") ///
										| strpos(advertiser, "MŰVELŐDÉSI") ///
										| strpos(advertiser, "MŰV.KÖZPONT") ///
										| strpos(advertiser, "HAGYOMÁNYOK") ///
										| strpos(advertiser, "AKADÉMIA") ///
										| strpos(advertiser, " TV") ///
										| strpos(advertiser, "MTVA") ///
										| strpos(advertiser, "KERT") ///
										| strpos(advertiser, "KULTURÁLIS") ///
										| strpos(advertiser, "PARK") ///
										| strpos(advertiser, "MŰV.HÁZ") ///
										| strpos(advertiser, "PALOTA") ///
										| strpos(advertiser, "KÖNYVTÁR") ///
										| strpos(advertiser, "JÁTÉKOK") ///
										| advertiser=="PLANETÁRIUM" ///
										| strpos(advertiser, "LEVÉLTÁR"))
 
gen health=.
replace health=0 if govt_agency==1
replace health=1 if govt_agency==1   & ministry!=1 & education!=1 & culture!=1 ///
										&(strpos(advertiser,"KÓRHÁZ") ///
										| strpos(advertiser,"SZOLG") ///
										| strpos(advertiser,"VAKOK") ///
										| strpos(advertiser,"OTTHON") ///
										| strpos(advertiser,"EGÉSZSÉG") ///
										| strpos(advertiser,"FÜRDŐ") ///
										| advertiser=="ORSZÁGOS ALAPELLÁTÁSI INTÉZET" ///
										| advertiser=="VAKOK ÁLLAMI INTÉZETE")
replace health=0 if tax_idadvertiser == 12147715	/*NEMZETI ÚTDÍJFIZ.SZOLG.ZRT.*/									
										
gen other_govt=. 
replace other_govt=0 if govt_agency==1
replace other_govt=1 if govt_agency==1 ///
		& ministry!=1 & education!=1 & culture!=1 & health!=1


*** Consistency checks
gen check1= ministry+culture+education+health+other_govt
tab check1 if govt_agency==1, miss
count if check1 != 1 & govt_agency == 1
assert r(N) == 0

foreach var of varlist culture education health other_govt ministry {
	display "`var'"
	bysort tax_idadvertiser: egen max_`var'=max(`var') if govt_agency==1
	replace `var'=max_`var'
	drop max_`var'
}
*
gen check2= culture+education+health+other_govt+ministry
tab check2 if govt_agency==1, miss
count if check2 != 1 & govt_agency == 1
assert r(N) == 0

drop check*



**************************
*** Define so/mo firms ***
**************************

* ever
*gen so_mo = so3 == 1 | mo3 == 1
*egen ever_so_mo = max(so_mo), by(tax_idadvertiser)

* in 1997
*gen so_mo_in_1997 = year == 1997 & (so3 == 1 | mo3 == 1)
*egen ever_so_mo_1997 = max(so_mo_1997), by(tax_idadvertiser)

* ever from 1997
*gen so_mo_from_1997 = (so3 == 1 | mo3 == 1) & year >= 1997
*egen ever_so_mo_from_1997 = max(so_mo_from_1997), by(tax_idadvertiser)
gen so_from_1997 = so3 == 1 & year >= 1997

* for at least 4 years
*egen so_mo_tag = tag(tax_idadvertiser year) if so_mo 
*egen so_mo_tag_tot = total(so_mo_tag), by(tax_idadvertiser)
*gen ever_so_mo_4y = so_mo_tag_tot >= 4

/* some statistics
foreach X of varlist ever_so_mo*{
	distinct tax_idadvertiser if `X'
	table `X', c(sum spending)
}
*/


********************************************************************************
* SAVE
********************************************************************************

save "temp/aux2_govt_do_vege.dta", replace


