* - Import advertisment data for printed media analysis

* - load data
* - keep only printed and online, for relevant years
* - fix bad taxids
* - create auxiliary ids for the missing
* - fix ownership statuses based on so3/other knowledge
* - idenify political parties/health insurers/churches/NGOs
* - create real spendings and total spending for firms


********************************************************************************
*1* LOAD DATA
********************************************************************************

*** CPI - each year price in percent of last year's in original data - has to be transformed all relate to one year: 2015

use "input/cpi/mnb_cpi_20200206_yearly.dta", clear

rename cpi cpi_raw

sort year
gen double cpi_raw2=.
replace cpi_raw2=cpi_raw if year==1993

foreach i of numlist 1994(1)2018 {
	replace cpi_raw2=(cpi_raw[_n]/100)*cpi_raw2[_n-1] if year==`i'
}

gen double _cpi_raw3=cpi_raw2 if year==2015
egen double cpi_raw3=min(_cpi_raw3)
gen double cpi_todividevaluewith=cpi_raw2/cpi_raw3
gen double cpi_tomultiplywith=1/cpi_todividevaluewith
	
tempfile cpi
save `cpi', replace


*** Advertiser data
use year month advertiser tax_idadvertiser piradvertiser ///
	do3_adv_fill fo3_adv_fill so3_adv_fill mo3_adv_fill ///
	media mediatype tematics publisher spending surface ///
	if year > 1994 | (year == 1994 & month > 5) ///
	using "input/Reklam-91-16/reklam_91_16.dta", clear	

gen market = "other"
replace market ="print" if tematics == "ORSZÁGOS KÖZÉLETI NAPILAPOK" ///
						   | tematics == "MEGYEI NAPILAPOK" ///
						   | media == "NAPI GAZDASÁG" ///
						   | media == "VILÁGGAZDASÁG"
replace market = "online" if mediatype=="INTERNET"
replace market = "tv" if strpos(mediatype, "TELEVÍZIÓ")
*keep if inlist(market, "print", "online", "tv")

foreach X in do3 fo3 so3 mo3{
	rename `X'_adv_fill `X'
}
*

	
********************************************************************************
* TAX-ID & ownership status corrections
********************************************************************************


*** Auxilliary id for observations without tax id. these id-s will contain negative values.
sort advertiser
egen newid = group(advertiser)
replace tax_idadvertiser = -newid if tax_idadvertiser==.
drop newid


*** Correct taxids

* so-mo
replace tax_idadvertiser=10356113 if strpos(advertiser,"MAGYAR TURISZTIKAI ÜGYNÖKSÉG") //changed name
replace tax_idadvertiser=12550753 if strpos(advertiser,"M.VILLAMOSENERGIA-IP. REND. RT") //MAVIR
replace tax_idadvertiser=10215418 if strpos(advertiser,"POSTABANK ÉRTÉKPAPÍRFORG.RT.") //jogelod
replace tax_idadvertiser=10907087 if strpos(advertiser,"CONCORDIA KÖZRAKTÁR RT.") //no good id
replace tax_idadvertiser=10987553 if strpos(advertiser, "BP.TEMETKEZÉSI INTÉZET")

* fo
replace tax_idadvertiser=30000890 if advertiser=="KLM" 

* do
replace tax_idadvertiser=10837410 if advertiser=="SZIGET IRODA KFT." 
replace tax_idadvertiser=11451479 if advertiser=="DUNAFERR CENTER HÁLÓZAT" 

qui{
	foreach i of varlist ?o3{
		foreach numso of numlist 10356113 12550753 10215418 10907087 10735363 12182888 12169210 10727201 14077340 10742833  14077340 10644371  {
			replace `i'=0 if tax_idadvertiser==`numso'
			replace so3=1 if tax_idadvertiser==`numso'
			*10735363 Zsolnay owned by APV
			*12182888 MTV
			*12169210 Magyar Radio
			*14077340 MNV
			*10727201 OVTT
			*10742833 Paks
			*14077340 APV
			*10644371 MFB
		}
		foreach numfo of numlist 30000890 {
			replace `i'=0 if tax_idadvertiser==`numfo'
			replace fo3=1 if tax_idadvertiser==`numfo'
		}
		foreach numdo of numlist 10837410 11451479 {
			replace `i'=0 if tax_idadvertiser==`numdo'
			replace do3=1 if tax_idadvertiser==`numdo'
		}
	}
}
*


*** Ownership corrections
gen o3_mod = 0


* Foreign firms
gen fo_name =  ///
	( strpos(advertiser, "GMBH") ///
	| strpos(advertiser, "LTD") ///
	| strpos(advertiser, "CORP") ///
	| strpos(advertiser, "PLC") ///
	| strpos(advertiser, "AIRLINES") ///
	| strpos(advertiser, "RYANAIR") ///
	| strpos(advertiser, "AIRWAYS") ///
	| strpos(advertiser, "S.Á.R.L") ///
	| strpos(advertiser, " INC") ///
	| strpos(advertiser, "S.A.") ///
	| strpos(advertiser, "PVISELET") ///
	| regexm(advertiser, "^AIR ") ///
	| advertiser == "TAP AIR PORTUGAL" ///
	| advertiser == "SWISS INTERNATIONAL AIR LINES" ///
	) ///
	& (tax_idadvertiser<0 | (tax_idadvertiser>0 & fo3==.))
replace fo_name = 0 if ///
	( strpos(advertiser, "INTERNATIONAL KFT") ///
	| strpos(advertiser,"ABB LÁNG LTD.") ///
	) ///
	& (tax_idadvertiser<0 | (tax_idadvertiser>0 & fo3==.))
replace fo_name = 1 if ///
	strpos(advertiser, "T-MOBILE") ///
	| strpos(advertiser, "T-KÁBEL")
	
egen proxied_foreign = max(fo_name), by(tax_idadvertiser)
tab advertiser if proxied_foreign != fo_name, m
replace o3_mod = o3_mod + 1 if proxied_foreign
foreach i of varlist ?o3{
	replace `i' = 0 if proxied_foreign
}
replace fo3 = 1 if proxied_foreign


* Domestic firms
gen do_name = ///
	( strpos(advertiser, "KFT.") ///
	| strpos(advertiser, "BT.") ///
	) ///
	& (tax_idadvertiser<0 | (tax_idadvertiser>0 & do3==.))

egen proxied_domestic = max(do_name), by(tax_idadvertiser)
tab advertiser if proxied_domestic != do_name
replace o3_mod = o3_mod + 1 if proxied_domestic
foreach i of varlist ?o3{
	replace `i' = 0 if proxied_domestic == 1
}
replace do3 = 1 if proxied_domestic


* Stateowned firms
gen so_name = ///
	strpos(advertiser, "KÖZÚTI IG") ///
	| advertiser=="AUTÓPÁLYA IGAZGATÓSÁG" /// 
	| advertiser=="MAGYAR TÁVIRATI IRODA"  ///
	| advertiser=="MAGYAR ÁLLAMI OPERAHÁZ"  ///
	| advertiser=="SZÉPMŰVÉSZETI MÚZEUM" ///
	| advertiser=="MAGYAR NEMZETI MÚZEUM" ///
	| advertiser=="MAGYAR NEMZETI GALÉRIA" ///
	| advertiser=="LUDWIG-KORTÁRS MŰV.MÚZEUM" ///
	| advertiser=="NÉPRAJZI MÚZEUM" ///
	| advertiser=="PETŐFI IRODALMI MÚZEUM" ///
	| advertiser=="URÁNIA NEMZETI FILMSZÍNHÁZ" ///
	| advertiser=="ORSZÁGOS SZÉCHENYI KÖNYVTÁR" ///
	| advertiser=="M.TERMÉSZETTUDOMÁNYI MÚZEUM" ///
	| advertiser=="ZENEAKADÉMIA BUDAPEST" ///
	| advertiser=="IPARMŰVÉSZETI MÚZEUM"
egen proxied_stateowned = max(so_name), by(tax_idadvertiser)
tab advertiser if proxied_stateowned != so_name
replace o3_mod = o3_mod + 1 if proxied_stateowned
foreach i of varlist ?o3{
	replace `i' = 0 if proxied_stateowned == 1
}
replace so3 = 1 if proxied_stateowned


* Political parties
gen pol_name = ///
	strpos(advertiser, "FIDESZ") ///
	| strpos(advertiser, "FIDELITAS") ///
	| strpos(advertiser, "SERES") ///
	| strpos(advertiser, "MSZP") ///
	| strpos(advertiser, "SZOCIALISTA") ///
	| strpos(advertiser, "MUNKÁSPÁRT") ///
	| strpos(advertiser, "SZDSZ") ///
	| strpos(advertiser, "NÉPPÁRT") ///
	| strpos(advertiser, "PÁRTJA") ///
	| strpos(advertiser, "MDF") ///
	| strpos(advertiser, "MKDSZ") ///
	| strpos(advertiser, "LIBERÁLIS") ///
	| strpos(advertiser, "KONZERVATÍV") ///
	| strpos(advertiser, "DEMOKRATÁK") ///
	| strpos(advertiser, "JOBBIK") ///
	| strpos(advertiser, "FKGP") ///
	| strpos(advertiser, "KDNP") ///
	| strpos(advertiser, "MIÉP") ///
	| strpos(advertiser, "KOALÍCIÓ") ///
	| strpos(advertiser, "KISGAZDÁK") ///
	| strpos(advertiser, "KISGAZDAPÁRT") ///
	| strpos(advertiser, "BALOLDAL") ///
	| strpos(advertiser, "SZDP") ///
	| strpos(advertiser, " PÁRT") ///
	| strpos(advertiser, "MAGYAR POLGÁRI EGYÜTTMŰKÖDÉS") ///
	| strpos(advertiser, "CIVIL ÖSSZEFOGÁS") ///
	| strpos(advertiser, "POLGÁRI SZÖVETSÉG")  ///
	| strpos(advertiser, "LEHET MÁS A POLITIKA") ///
	| advertiser == "MODERN MAGYARORSZÁG MOZGALOM"
replace pol_name = 0 if ///
	strpos(advertiser, "CSOMIÉP KFT.") ///
	| strpos(advertiser, "AUTÓS NAGYKOALÍCIÓ")
egen pol_party = max(pol_name), by(tax_idadvertiser)
tab advertiser if pol_party != pol_name
replace o3_mod = o3_mod + 1 if pol_party
foreach i of varlist ?o3{
	replace `i' = . if pol_party == 1
}
replace tax_idadvertiser=-999999 if ///
		  strpos(advertiser, "FIDESZ") ///
		| strpos(advertiser, "KDNP") ///
		| strpos(advertiser, "FIDELITAS") ///
		| strpos(advertiser, "KERESZTÉNYDEMOKRATA NÉPPÁRT") ///
		| strpos(advertiser, "FKGP") 
replace tax_idadvertiser=-999998 if pol_party & tax_idadvertiser != -999999 


* Check if ownership status was modified more than once
tab advertiser if o3_mod>1


*** Drop some categories

* Health Insurance and Private Pension Funds
gen health_name = ///
	( strpos(advertiser, "EGÉSZSÉGPÉNZTÁR") ///
	| strpos(advertiser, "EGÉSZSÉGPTÁR") ///
	| strpos(advertiser, "NYUGDÍJPÉNZTÁR") ///
	| strpos(advertiser, "NYUGDÍJPTÁR") ///
	| strpos(advertiser, "EG.PTÁR.") ///
	) ///
	& (tax_idadvertiser<0 | (tax_idadvertiser>0 & fo3==.))
	
egen proxied_health = max(health_name), by(tax_idadvertiser)
list if proxied_health != health_name
drop if proxied_health 
	
	
* Churches
gen church_name = ///
	strpos(advertiser, " EGYHÁZ") ///
	| strpos(advertiser, "GYÜLEKEZET") ///
	| strpos(advertiser, "HITKÖZ") ///
	| strpos(advertiser, "KATOLIKUS")
egen proxied_church = max(church_name), by(tax_idadvertiser)
tab advertiser if proxied_church != church_name
drop if proxied_church 


* Courts
gen court_name = ///
	strpos(advertiser, " BÍRÓSÁG") ///
	| strpos(advertiser, "ÜGYÉSZSÉG") 
egen proxied_court = max(court_name), by(tax_idadvertiser)
tab advertiser if proxied_court != court_name
drop if proxied_court 


*** Non-firms, NGOs 
gen ngo_name = tax_idadvertiser >= 18000000 & tax_idadvertiser < 20000000 ///
		& pol_party != 1 & so3 != 0 ///
		& advertiser != "NEMZETI KONZULTÁCIÓ" ///
		& advertiser != "NEMZETI KULTURÁLIS ALAP" ///
		& advertiser != "ORSZÁGOS VÁLASZTÁSI IRODA" ///
		& advertiser != "REGIONÁLIS VÁLLALK.FEJL.ALAP." ///
		& advertiser != "ZENEAKADÉMIA BUDAPEST" ///
		& advertiser != "MAGYAR OLIMPIAI BIZOTTSÁG" ///
		& advertiser != "ZSIGMOND KIRÁLY FŐISKOLA" ///
		& advertiser != "KODOLÁNYI JÁNOS FŐISK.SZFVÁR." ///
		& advertiser != "CENTRAL EUROPEAN UNIVERSITY" ///
		& advertiser != "INTERNATIONAL BUSINESS SCHOOL"
		
egen proxied_ngo = max(ngo_name), by(tax_idadvertiser)
gen ngo = ngo_name
tab advertiser if proxied_ngo != ngo_name
drop if proxied_ngo 

	
*** OTHER MISCELLANEOUS errors, by Feri
gen other_name = 0
local names "NAGYKÖVETSÉG IPARKAMARA AGRÁRKAMARA EURÓPAI SZÖVETKEZET FELÜGYELET ALAPÍTV EGYESÜLET KHT KÖZALAPÍTVÁNY"
foreach i of local names {
	replace other_name = 1 if strpos(advertiser, "`i'") &  pol_party != 1 
}
replace other_name = 1 if ///
	(strpos(advertiser, "IDEGENFOR") ///
	| strpos(advertiser, "KER.KAMARA") ///
	| strpos(advertiser, "ALAP.") ///
	| advertiser=="ÓBUDAI TÁRSASKÖR" ///
	| advertiser=="EGYÉB HIRDETŐ" ///
	| tax_idadvertiser==1203776 ///
	) ///
	& pol_party != 1 & so3 != .
replace other_name = 1 if ///
	advertiser=="APRÓHIRDETÉS" ///
	| advertiser=="SZÍVÜGY" ///
	| advertiser=="MAGYAR KÖNYVKLUB" ///
	| advertiser=="ÁLLAMI GAZDASÁG" ///
	| advertiser=="DE-MAX EGÉSZSÉGÜGYI CENTRUM" ///
	| advertiser=="TUNÉZIAI IDEGENFORG.HIVATAL" ///
	| advertiser=="TAKE IT" ///
	| advertiser=="MAGYAR ÁRAMSZOLGÁLTATÓ KFT." ///
	| advertiser=="KITTENBERGER K.NONPROFIT KFT." ///
	| advertiser=="VÁROSI VAGYONKEZELŐ" ///
	| advertiser=="HÍRLAPKIADÓ VÁLLALAT" ///
	| advertiser=="CSEH TURISZTIKAI HIVATAL" ///
	| advertiser=="KUBAI IDEGENFORG.HIVATAL" ///
	| advertiser=="ALSÓ-AUSZTRIA IDEGENFORG.HIV." ///
	| advertiser=="SZICÍLIAI IDEGENFORG.HIVATAL" ///
	| advertiser=="ROMÁN TURISZTIKAI HIVATAL" ///
	| advertiser=="SVÁJCI TURISZTIKAI HIVATAL"
replace other_name = 0 if advertiser == "HÉVÍZGYÓGYFÜRDŐ KHT." ///
		| advertiser == "REGIONÁLIS VÁLLALK.FEJL.ALAP."
egen proxied_others = max(other_name), by(tax_idadvertiser)
tab advertiser if proxied_others != other_name
drop if proxied_others 
		
		

********************************************************************************
* REAL SPENDING
********************************************************************************

merge m:1 year using `cpi', keep(3) nogen
replace spending=spending*cpi_tomultiplywith
egen start = min(year), by(tax_idadvertiser)
egen end = max(year), by(tax_idadvertiser)



********************************************************************************
* SAVE
********************************************************************************
drop *_name proxied_* o3_mod cpi_tomultiplywith 
save "temp/aux1_import_do_end.dta", replace


