********************************************************************************
*** SELECTING THE LARGEST ADVERTISERS
********************************************************************************

* Keep only the largest advertisers
* - 500 largest domestic firms
* - 200 largest state-owned and muni-owned firms
* - all government agencies
* - all local government agencies
* - 2 party blocks: Fidesz-KDNP and all other parties


*** Import data
use "temp/aux2_govt_do_vege.dta", clear
drop if market == "other"
levelsof market, local(markets)


foreach m of local markets{

	*** Import data
	use "temp/aux2_govt_do_vege.dta", clear
	keep if market=="`m'"
	drop if mo3 == 1 | localgov == 1 | pol_party == 1

	
	preserve

		*** Selecting the largest spenders
		collapse (sum) spending (max) do3 ever_so=so_from_1997 govt_agency localgov pol_party, by(tax_idadvertiser)
		gen type=.
		replace type=1 if !missing(do3) | govt_agency | localgov | pol_party // if do3 non missing we have full timeframe ownership info from bsheet
		replace type=2 if ever_so==1
		replace type=3 if govt_agency==1
		replace type=4 if localgov==1
		replace type=5 if pol_party==1

		gsort type -spending
		by type: gen ranking=_n
		drop spending
		* keep if (ranking<=500 & type==1) | (ranking<=200 & type==2) | type==3 | type==4 | type==5
		keep if (type==1 & ranking<=500) | type==2 | type==3 

		tempfile largest_advertiser
		save `largest_advertiser', replace


		*** Importing balance data for industries
		use originalid year emp sales17 teaor03_1d teaor03_2d ///
			using "input/balance-sheet-1992-2017-derived/balance_sheet_92_17.dta", clear
		rename originalid tax_idadvertiser

		egen ind_1d=mode(teaor03_1d), by(tax_idadvertiser) minmode
		egen ind_2d=mode(teaor03_2d), by(tax_idadvertiser) minmode

		collapse (mean) emp sales17 (first) ind_*, by(tax_idadvertiser) 
		merge 1:1 tax_idadvertiser using `largest_advertiser', keep(2 3) nogen

		gen byte so_ind = inlist(ind_1d, "D", "E", "G", "I", "J", "K", "O")

		save `largest_advertiser', replace
		
	restore

	
	*** Merge back
	merge m:1 tax_idadvertiser using `largest_advertiser', keep(3) nogen
	bysort type: distinct tax_idadvertiser

	
	*** Define types for the analysis	
	rename type type_old
	gen type=.
	replace type=1 if do3==1
	replace type=2 if fo3==1
	replace type=3 if so3==1
	replace type=4 if mo3==1
	replace type=5 if govt_agency==1
	replace type=6 if localgov==1
	replace type=7 if pol_party==1
	label define typelabel 1 "do3" 2 "fo3" 3 "so3" 4 "mo3" 5 "govt_agency" 6 "localgov" 7 "pol_party"
	label values type typelabel

	drop if inlist(type, 4, 6, 7)	
	
	egen check1 = sd(type), by(tax_idadvertiser year)
	count if !missing(check1) & check1 != 0
	assert r(N) == 0

	egen check2 = sd(type), by(tax_idadvertiser)
	count if !missing(check2) & check2 != 0 & type > 4
	assert r(N) == 0

	drop check*
	
		
	*** Save
	save "temp/aux3_largest_do_vege_`m'.dta", replace
	
}
