*** Change the structure of the data 


* Generate cycle variables
gen cycle=1 if (year==1994&month>=6)|(year>=1995&year<=1997)|(year==1998&month<6)
replace cycle=2 if (year==1998&month>=6)|(year>=1999&year<=2001)|(year==2002&month<6)
replace cycle=3 if (year==2002&month>=6)|(year>=2003&year<=2005)|(year==2006&month<6)
replace cycle=4 if (year==2006&month>=6)|(year>=2007&year<=2009)|(year==2010&month<6)
replace cycle=5 if (year==2010&month>=6)|(year>=2011)
label define cyclelabel 1 "1994-98" 2 "1998-02" 3 "2002-06" 4 "2006-10" 5 "2010-14"
label values cycle cyclelabel
*tab cycle, gen(dcycle)
*drop dcycle1


* Create ownership variable on a cycle frequency based on majority of months 
sort tax_idadvertiser year month
fillin tax_idadvertiser year month

bysort tax_idadvertiser year: egen type2 = min(type) 
bysort tax_idadvertiser cycle: egen type_cycle = mode(type2), maxmode
drop if cycle==.


* Collapse
collapse (sum) spending surface (first) ind_1d emp sales17 advertiser type=type_cycle type_old start end ///
education culture health ministry other_govt, by(tax_idadvertiser media_color cycle)


* Adjust for different cycle length
replace spending=spending/4 if cycle==1|cycle==2|cycle==3|cycle==4
replace spending=spending/4.58 if cycle==5
replace surface=surface/4 if cycle==1|cycle==2|cycle==3|cycle==4
replace surface=surface/4.58 if cycle==5


* Creating a balanced dataset
fillin tax_idadvertiser cycle media_color
sort tax_idadvertiser cycle media_color

replace spending=0 if spending==.
replace surface=0 if surface==.


* Fill forward
sort tax_idadvertiser cycle _fillin
by tax_idadvertiser: gen orderid=_n
tsset tax_idadvertiser orderid
tsfill
foreach v of varlist ind_1d emp sales17 advertiser type type_old start end education culture health ministry other_govt {
	bysort tax_idadvertiser: carryforward `v', gen(`v'_new)
}
foreach v of varlist ind_1d emp sales17 advertiser type type_old start end education culture health ministry other_govt {
	drop `v'
	rename `v'_new `v'
}
drop orderid


* Fill backward
gen negcycle=-cycle
sort tax_idadvertiser negcycle _fillin
by tax_idadvertiser: gen orderid=_n
tsset tax_idadvertiser orderid
tsfill
foreach v of varlist ind_1d emp sales17 advertiser type type_old start end other_govt ministry health culture education{
	bysort tax_idadvertiser: carryforward `v', gen(`v'_new)
}

foreach v of varlist ind_1d emp sales17 advertiser type type_old start end other_govt ministry health culture education{
	drop `v'
	rename `v'_new `v'
}
drop negcycle orderid 


* Drop firms who started in the very end of the cycle
sort tax_idadvertiser cycle media_color
drop if start>1997&cycle<=1&(type==1|type==2|type==3|type==4 |type==5)
drop if start>2001&cycle<=2&(type==1|type==2|type==3|type==4 |type==5)
drop if start>2005&cycle<=3&(type==1|type==2|type==3|type==4 |type==5)
drop if start>2009&cycle<=4&(type==1|type==2|type==3|type==4 |type==5)
drop if end<=1997&cycle>1&(type==1|type==2|type==3|type==4 |type==5)
drop if end<=2001&cycle>2&(type==1|type==2|type==3|type==4 |type==5)
drop if end<=2005&cycle>3&(type==1|type==2|type==3|type==4|type==5)
drop if end<=2009&cycle>4&(type==1|type==2|type==3|type==4|type==5)


