clear all
pause on



*******************
*** START *********
*******************

use "temp/aux3_largest_do_vege_print.dta", clear
append using "temp/aux3_largest_do_vege_online.dta"
drop if type==5 & (education==1 | health==1 | culture==1)  


*************************
*** Data manipulation ***
*************************
keep if media=="MAGYAR NEMZET"|media=="NÉPSZABADSÁG"|mediatype=="INTERNET"

replace media="nol" if media=="NÉPSZABADSÁG"
replace media="mno" if media=="MAGYAR NEMZET"

replace media="index" if strpos(media,"CEMP")
replace media="origo" if strpos(media,"ORIGO")
replace media="24.hu" if strpos(media,"CENTRAL MÉDIACSOPORT")
replace media="hvg" if strpos(media,"HVG")
replace media="ringier" if strpos(media,"RINGIER")|strpos(media,"AXEL SPRINGER")

keep if media=="nol" | media=="mno" | media=="index" | media=="origo"

gen period = .
replace period=1 if (year==2013|(year==2014&month<6))& (media=="index"|media=="origo")
replace period=2 if ((year==2014&month>=6)|year==2015) & (media=="index"|media=="origo")
replace period=3 if year>=2016 &(media=="index"|media=="origo")
replace period=1 if (year==2013|year==2014|(year==2015&month<2))&(media=="nol"|media=="mno")
replace period=2 if ((year==2015&month>=2)|year==2016)&(media=="nol"|media=="mno")
keep if period!=.

egen totalspend_pub_o = sum(spending) if (type==3|type==5)&(media=="index"|media=="origo"), by(year)
tabstat totalspend_pub_o, by(year)
egen totalspend_pri_o = sum(spending) if (type==1|type==2)&(media=="index"|media=="origo"), by(year)
tabstat totalspend_pri_o, by(year)

*tab type, nolabel
egen totalspend_pub_p = sum(spending) if (type==3|type==5)&(media=="mno"|media=="nol"), by(year)
tabstat totalspend_pub_p, by(year)
egen totalspend_pri_p = sum(spending) if (type==1|type==2)&(media=="mno"|media=="nol"), by(year)
tabstat totalspend_pri_p, by(year)



gen online = (media=="origo"|media=="index")

preserve
	collapse (sum) spending, by(tax_idadvertiser period online type)
	gsort tax_idadvertiser online period -spending
	by tax_idadvertiser online period: gen ranking = _n
	keep if ranking == 1
	keep tax_idadvertiser online period type
	tempfile types
	save `types', replace
restore


collapse (sum) spending surface (first) advertiser /*type*/ start end ind_1d emp, by(tax_idadvertiser media period)
gen online = (media=="origo"|media=="index")
merge m:1 tax_idadvertiser online period using `types'
count if _merge != 3
assert r(N) == 0
drop _merge online



*** Filling in 0 to missing period advertiser cells ****
fillin tax_idadvertiser media period
sort tax_idadvertiser media period

replace spending=0 if spending==.
replace surface=0 if surface==.

bysort tax_idadvertiser period: egen type2 = min(type) 
drop type
rename type2 type


sort tax_idadvertiser period _fillin
by tax_idadvertiser: gen orderid=_n
tsset tax_idadvertiser orderid

foreach v of varlist advertiser type start end ind_1d emp {
	bysort tax_idadvertiser: carryforward `v', gen(`v'_new)
}
foreach v of varlist advertiser type start end ind_1d emp {
	drop `v'
	rename `v'_new `v'
}
drop orderid

gen negperiod = -period

sort tax_idadvertiser negperiod _fillin
by tax_idadvertiser: gen orderid=_n
tsset tax_idadvertiser orderid

foreach v of varlist advertiser type start end ind_1d emp {
	bysort tax_idadvertiser: carryforward `v', gen(`v'_new)
}

foreach v of varlist advertiser type start end ind_1d emp {
	drop `v'
	rename `v'_new `v'
}
drop negperiod orderid _fillin


* Delete those advertiser-periods when advertiser did not exist
drop if start>2014&period==1&(media=="index"|media=="origo")
drop if start>2015&period==2&(media=="index"|media=="origo")
drop if end<2013&(media=="index"|media=="origo")
drop if end<2014&period==2&(media=="index"|media=="origo")
drop if end<2016&period==3&(media=="index"|media=="origo")
drop if start>2014&period==1&(media=="nol"|media=="mno")
drop if start>2016&period==2&(media=="nol"|media=="mno")
drop if end<2013&(media=="nol"|media=="mno")
drop if end<2016&period==2&(media=="nol"|media=="mno")

sort tax_idadvertiser media period


**** Filling in ends here
gen online = (media=="origo"|media=="index")
gen pub = (type==3|type==5)

egen spending_all=sum(spending), by(tax_idadvertiser period online)
gen spending_share=.
replace spending_share=spending/spending_all if spending_all!=0


replace spending_all=spending_all/(17/12) if period==1&(media=="index"|media=="origo") /*Augmenting spending_all to express yearly spending*/
replace spending_all=spending_all/(19/12) if period==2&(media=="index"|media=="origo") /*Augmenting spending_all to express yearly spending*/

replace spending_all=spending_all/(25/12) if period==1&(media=="nol"|media=="mno") /*Augmenting spending_all to express yearly spending*/
replace spending_all=spending_all/(23/12) if period==2&media=="mno" /*Augmenting spending_all to express yearly spending*/
replace spending_all=spending_all/(21/12) if period==2&media=="nol" /*Augmenting spending_all to express yearly spending*/

replace spending_share = .99 if spending_share==1
replace spending_share = .01 if spending_share==0
gen lodds = log(spending_share/(1-spending_share)) 

sort media period

keep if lodds!=.
keep if media=="origo"|media=="mno"

keep online tax_idadvertiser spending_all lodds pub period


*** Reshaping the data for the three different samples
* Print
preserve
	keep if online == 0 
	sort tax_idadvertiser period
	 
	reshape wide spending_all lodds pub, i(tax_idadvertiser) j(period) 
	export delimited using "temp/microdata_adv_print.csv", replace
restore

* Online
preserve
	keep if online == 1 
	sort tax_idadvertiser period
		 
	reshape wide spending_all lodds pub, i(tax_idadvertiser) j(period) 
	export delimited using "temp/microdata_adv_online.csv", replace
restore

* Pooled
preserve
	gen market_time = 1 if online==1&period==1
	replace market_time = 2 if online==1&period==2
	replace market_time = 3 if online==1&period==3
	replace market_time = 4 if online==0&period==1
	replace market_time = 5 if online==0&period==2

	drop online period
	sort tax_idadvertiser market_time 
	 
	reshape wide spending_all lodds pub, i(tax_idadvertiser) j(market_time) 
	export delimited using "temp/microdata_adv_pooled.csv", replace
restore

