*** Get ready
clear all
pause on
set more off



*****************************************
*** Summary statistics on advertising ***
*****************************************

foreach m in print online{
	use "temp/aux3_largest_do_vege_`m'.dta", clear

	gen N_advertiser = .
	levelsof type_old, local(types)
	foreach X of local types{
		distinct tax_idadvertiser if type_old == `X'
		replace N_advertiser = `r(ndistinct)' if type_old == `X'
	}
	*

	collapse (mean) N_advertiser (sum) spending, by(type_old)

	tostring type_old, replace
	replace type_old = "1_Private firm" if type_old == "1"
	replace type_old = "2_State-owned firm" if type_old == "2"
	replace type_old = "3_Govt. agency" if type_old == "3"

	gen N_advertiser_share_`m' = string(N_advertiser, "%2.0f")

	sum spending, meanonly
	gen spending_share_`m' = string(spending/`r(sum)'*100, "%2.1f") + "\%"

	set obs 4
	replace type_old = "4_Total spending (USD M)" in 4
	local sum_spend = string(`r(sum)'/1000/279.46, "%2.0f") 
	if strlen("`sum_spend'") == 4{
		local sum_spend = substr("`sum_spend'", 1, 1) + "," + substr("`sum_spend'", 2, 3)
	}
	replace spending_share_`m' = "`sum_spend'" in 4

	drop N_advertiser spending 

	tempfile summary_stat_`m'
	save `summary_stat_`m'', replace
}
*

use `summary_stat_print', clear
merge 1:1 type_old using `summary_stat_online'
count if _merge != 3
assert r(N) == 0
drop _merge

split type_old, parse("_")
drop type_old type_old1
order type_old2
dataout, save("output/table3.tex") replace tex 
*/


****************************************
*** Market shares of connected media ***
****************************************

use "temp/aux3_largest_do_vege_print.dta", clear
append using "temp/aux3_largest_do_vege_online.dta"
keep if inlist(type, 1, 2)
keep if inlist(year, 2000, 2006, 2012, 2016)


*** Media color
gen media_color = "independent"

* printed - right 
replace media_color = "right" if media=="MAGYAR NEMZET" & year>=2000 & year<=2014
replace media_color = "right" if media=="NAPI MAGYARORSZÁG"
replace media_color = "right" if media=="MAGYAR HÍRLAP" & year>2005
replace media_color = "right" if strpos(media, "METROPOL")& year>2011 & year<=2014
replace media_color = "right" if media=="NAPI GAZDASÁG" & year>2013
replace media_color = "right" if media=="MAGYAR IDŐK"
replace media_color = "right" if media=="RIPOSZT"
replace media_color = "right" if media=="LOKÁL"
replace media_color = "right" if (media=="24 ÓRA"|media=="BÉKÉS MEGYEI HÍRLAP"| ///
								media=="DUNAÚJVÁROSI HÍRLAP"|media=="ÚJ DUNÁNTÚLI NAPLÓ"|media=="FEJÉR MEGYEI HÍRLAP"| ///
								media=="HEVES MEGYEI HÍRLAP"|media=="NAPLÓ"| media=="PETŐFI NÉPE"| media=="SOMOGYI HÍRLAP"| /// 
								media=="TOLNAI NÉPÚJSÁG" | strpos(media, "ÚJ NÉPLAP")| media=="VAS NÉPE" | media=="ZALAI HÍRLAP") & year==2016
replace media_color = "right" if media=="VILÁGGAZDASÁG" & year==2016

* printed - left
replace media_color = "left" if media=="MAGYAR HÍRLAP"&year<=2005
replace media_color = "left" if media=="NÉPSZABADSÁG"
replace media_color = "left" if media=="NÉPSZAVA"
replace media_color = "left" if strpos(media,"HVG")
replace media_color = "left" if media=="168 ÓRA"
replace media_color = "left" if media=="MAGYAR NARANCS"
replace media_color = "left" if media=="SZABAD FÖLD"

* online - right 
replace media_color = "independent" if market == "online"
replace media_color = "right" if strpos(media,"ORIGO") & year>=2014


*** Compute market shares
foreach X in left right{
	gen spending_`X' = spending if media_color == "`X'"
}
*

collapse (sum) spending*, by(market year)
fillin  market year
foreach X in left right{
	gen spending_share`X' = string(spending_`X'/spending*100, "%2.0f") + "\%"
	replace spending_share`X' = "" if _fillin == 1
}
keep year market spending_share*
reshape long spending_share, i(market year) j(pol, string)
reshape wide spending_share, i(market pol) j(year)

gen order_market = market == "online"
gen order_pol = pol == "left"

set obs 6
replace order_market = 0 if missing(order_market)
replace market = "Next two rows: right-shares" in 5
replace order_pol = -1 in 5
replace market = "Next two rows: left-shares" in 6
replace order_pol = 0.5 in 6

sort order_pol order_market
drop order_* pol

replace market = "Online" if market == "online"
replace market = "Print" if market == "print"

* dataout, save("output/captured_market_shares.tex") replace tex 
*/



*************************
*** Top media outlets ***
*************************
local year = 2014


use "input/circulation/circulation_16_yearly.dta", clear
keep if inlist(year, `year')
rename totalspread circulation
drop id
tempfile circulation
save `circulation', replace

import delimited "temp/news-outlets-reader-count-pc-adjusted-quarterly-sum.csv", clear
keep if inlist(year, `year')
collapse (sum) circulation=visitor, by(media year)
replace circulation = circulation/365
append using `circulation'
save `circulation', replace


use "temp/aux3_largest_do_vege_online.dta", clear

replace media = "index" if strpos(media, "CEMP")
replace media = "origo" if strpos(media, "ORIGO")
replace media = "24.hu group" if strpos(media, "CENTRAL MÉDIACSOPORT")
replace media = "hvg" if strpos(media, "HVG")
replace media = "ringier" if strpos(media,"RINGIER") | strpos(media,"AXEL SPRINGER")
keep if inlist(media, "index", "origo", "24.hu group", "hvg")


append using "temp/aux3_largest_do_vege_print.dta"

keep if inlist(type, 1, 2)
keep if inlist(year, `year')

replace media = "METROPOL" if media == "METROPOL BUDAPEST"

replace market = "1_Political daily" if market == "print"
replace market = "2_Tabloid" if inlist(media, "BLIKK", "BORS", "MAI NAP", "LOKÁL", "RIPOST")
replace market = "3_Regional" if tematics == "MEGYEI NAPILAPOK"
replace market = "4_Online" if market == "online"



collapse (sum) spending, by(market media year)
merge 1:1 media year using `circulation', keep(1 3) nogen
drop year

replace spending = spending/1000/279.46
replace circulation = circulation/1000


*** Shares
preserve

	keep if inlist(market, "1_Political daily", "4_Online")

	foreach X in spending circulation{
		egen `X'_tot = total(`X'), by(market)
		gen `X'_share_num = `X'/`X'_tot
		gen `X'_share = string(`X'_share_num*100, "%2.0f") + "\%" if !missing(`X'_share_num)
	}
	*

	gsort market -spending_share_num
	by market: gen ranking = _n 
	keep if ranking <= 5 

	replace media = ustrtitle(media)
	replace media = subinstr(media, ".Hu", ".hu", .)
	replace media = subinstr(media, "Group", "group", .)

	sort market ranking
	keep media *_share

	rename media x
	rename spending_share spending
	rename circulation_share circulation

	tempfile shares
	save `shares', replace

restore	


*** Totals
collapse (sum) spending_num=spending circulation_num=circulation, by(market)

split market, parse("_")
rename market2 x

foreach X in spending circulation{
	gen `X' = string(`X'_num, "%2.0f")
	replace `X' = substr(`X', 1, 1) + "," + substr(`X', 2, 3) if strlen(`X') == 4
}

drop *_num market*

append using `shares'
	
dataout, save("output/table2.tex") replace tex 



**********************************
*** Structural model scenarios ***
**********************************

use "temp/aux3_largest_do_vege_online.dta", clear
append using "temp/aux3_largest_do_vege_print.dta"

replace media = "index" if strpos(media, "CEMP")
replace media = "origo" if strpos(media, "ORIGO")

keep if inlist(media, "index", "origo", "MAGYAR NEMZET", "NÉPSZABADSÁG")
keep if inlist(year, 2013, 2016)

gen gov_pub = education + health + culture if type == 5
drop if gov_pub == 1
replace type = 1 if type == 2
replace type = 3 if type == 5

collapse (sum) spending, by(market year type)
keep if (market == "online" & type == 3) | (market == "print" & type == 1)
drop type

replace spending = spending/1000/279.46
reshape wide spending, i(market) j(year)
gen d_spending = (spending2016-spending2013)/spending2013*100

* dataout, save("output/spending_2013_2016.tex") replace tex 


**********************
*** Online content ***
**********************

import delimited "input/media_analysis/media_analysis_results.csv", encoding(UTF-8) clear
keep if inlist(page, "444HU", "HVG", "INDEX", "MH", "MNO", "NOL", "ORIGO")

split date, parse("_")
destring date?, replace
rename date1 year
rename date2 month

keep if year >= 2013 & year <= 2016
drop if year == 2016 & month >= 11

local i = 0
foreach X of varlist mnbalapítvány- zugló_papcsák_hangfelvétel{
	local i =  `i' + 1
}
*
gen x = 1

display "Number of sets of keywords: `i'"
table x, c(sum any sum all)


