* Get ready
clear all
pause on
set more off


*******************
*** START *********
*******************


use "temp/aux3_largest_do_vege_print.dta", clear
keep if year <= 2014
drop if type == 4

* Coloring newspapers
gen media_color="independent"
do coloring_print


* Preparation for the regressions
do regression_structure_print



***************************
*** Run the regressions ***
***************************


*** Table 3 Central political power and advertising composition


* Right government dummy
gen rightgov=0
replace rightgov=1 if cycle==2|cycle==5


* Spending shares
egen spending_all=sum(spending), by(tax_idadvertiser cycle)
egen spending_all_con=sum(spending) if media_color=="left"|media_color=="right", by(tax_idadvertiser cycle)
gen spending_share=.
gen spending_share_con=.
replace spending_share=spending/spending_all if spending_all!=0 
replace spending_share_con=spending/spending_all_con if spending_all_con!=0

egen totspend=sum(spending), by(tax_idadvertiser)
egen totspend_con=sum(spending) if media_color=="left"|media_color=="right", by(tax_idadvertiser)
gen spending_norm=spending_all_con/totspend_con


* Surface shares
egen surface_all=sum(surface), by(tax_idadvertiser cycle)
egen surface_all_con=sum(surface) if media_color=="left"|media_color=="right", by(tax_idadvertiser cycle)
gen surface_share=.
gen surface_share_con=.
replace surface_share=surface/surface_all if surface_all!=0 
replace surface_share_con=surface/surface_all_con if surface_all!=0 


* Ownership dummies
gen foreign=0
replace foreign=1 if type==2
gen stateowned=0
replace stateowned=1 if type==3
gen muniowned=0
replace muniowned=1 if type==4


*Industry dummies
gen ind1=0
replace ind1=1 if ind_1d=="G"
gen ind2=0
replace ind2=1 if ind_1d=="D"
gen ind3=0
replace ind3=1 if ind_1d=="J"
gen ind4=0
replace ind4=1 if ind_1d=="I"
gen ind5=0
replace ind5=1 if ind_1d=="K"
gen ind6=0
replace ind6=1 if ind1==0&ind2==0&ind3==0&ind4==0&ind5==0


* Government agency and localgov type dummies
gen govt_agency = 0
gen gov_admin = 0
gen gov_pub = 0
gen localgov = 0
gen pol_party = 0
replace govt_agency = 1 if type==5
replace gov_admin = ministry + other_govt if type==5
replace gov_pub = education + health + culture if type==5
replace localgov = 1 if type==6
replace pol_party = 1 if type==7


* Right government x ownership dummies
gen rightgov_stateowned=rightgov*stateowned
gen rightgov_muniownedowned=rightgov*muniowned
gen rightgov_gov=rightgov*govt_agency
gen rightgov_loc=rightgov*localgov
gen rightgov_for=rightgov*foreign
gen rightgov_gov_admin = rightgov*gov_admin
gen rightgov_gov_pub = rightgov*gov_pub


* Total spending per cycle and type
egen fullspend=sum(spending), by(cycle type)


* Right government x industry/emp/sales
gen lemp=log(emp)
gen lsales=log(sales17)
foreach v of numlist 1/6 {
	gen rightgov_ind`v'=rightgov*ind`v'
}
drop rightgov_ind1
drop ind1
gen rightgov_lemp=rightgov*lemp
gen rightgov_lsales=rightgov*lsales


* Labels for the regression output	
lab var spending_share_con "R/(R+L)"
lab var stateowned  "State-owned"
lab var gov_admin  "Govt. agency (admin)"
lab var gov_pub  "Govt. agency (public good)"
lab var rightgov_stateowned  "State-owned $\times$ right cycle"
lab var rightgov_gov_admin  "Govt. agency (admin) $\times$ right cycle"
lab var rightgov_gov_pub  "Govt. agency (public good) $\times$ right cycle"
lab var ind2 "Manufacturing"
lab var ind3 "Finance"
lab var ind4 "Transportation"
lab var ind5 "Real estate"
lab var ind6 "Other"
lab var rightgov_ind2 "Manufacturing $\times$ right cycle"
lab var rightgov_ind3 "Finance $\times$ right cycle"
lab var rightgov_ind4 "Transportation $\times$ right cycle"
lab var rightgov_ind5 "Real estate $\times$ right cycle"
lab var rightgov_ind6 "Other $\times$ right cycle"
lab var lemp "Log(employment)"
lab var lsales "Log(sales)" 
lab var rightgov_lemp "Log(employment) $\times$ right cycle"
lab var rightgov_lsales "Log(sales) $\times$ right cycle" 


* Regressions
eststo clear
quietly{
	eststo: reg spending_share_con rightgov_stateowned rightgov_gov_admin rightgov_gov_pub stateowned gov_admin gov_pub i.cycle ///
	if media_color=="right"&(type==1|type==2|type==3|type==5)&totspend_con>0, cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local cycle_fe "X"
	estadd local weighted ""
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"

	xtset tax_idadvertiser
	eststo: xtreg spending_share_con rightgov_stateowned rightgov_gov_admin rightgov_gov_pub i.cycle ///
	if media_color=="right"&(type==1|type==2|type==3|type==5)&totspend_con>0, fe cluster(tax_idadvertiser) 
	estadd local adv_fe "X"
	estadd local cycle_fe "X"
	estadd local weighted ""
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"

	eststo: reg spending_share_con rightgov_stateowned rightgov_gov_admin rightgov_gov_pub stateowned gov_admin gov_pub i.cycle ///
	[aw=totspend_con] if media_color=="right"&(type==1|type==2|type==3|type==5), cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local cycle_fe "X"
	estadd local weighted "X"
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"

	xtset tax_idadvertiser
	eststo: xtreg spending_share_con rightgov_stateowned rightgov_gov_admin rightgov_gov_pub i.cycle ///
	[aw=totspend_con] if media_color=="right"&(type==1|type==2|type==3|type==5), fe cluster(tax_idadvertiser) 
	estadd local adv_fe "X"
	estadd local cycle_fe "X"
	estadd local weighted "X"
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"
}
esttab using "output/tableA2.tex", se star(* 0.10 ** 0.05 *** 0.01) label drop(*cycle _cons) replace ///
	scalars("adv_fe Advertiser FE" "cycle_fe Cycle FE" "weighted Weighted") 
	*scalars("adv_fe Advertiser FE" "cycle_fe Cycle FE" "weighted Weighted" "n_state State" "n_muni Muni" "n_gov_admin Gov admin" "n_gov_pub Gov pub" "n_localgov Localgov" "n_pol_party Pol party" "n_priv Private" "n_firms Firms") 




*** Heterogeneity among private advertisers in two main dailies

eststo clear
quietly{
	eststo: reg spending_share_con rightgov_ind* ind2 ind3 ind4 ind5 ind6 i.cycle ///
	if media_color=="right" & (type==1|type==2) & totspend_con>0, cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local cycle_fe "X"
	estadd local weighted ""

	eststo: reg spending_share_con rightgov_lemp lemp i.cycle ///
	if media_color=="right" & (type==1|type==2) & totspend_con>0, cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local cycle_fe "X"
	estadd local weighted ""
	
	eststo: reg spending_share_con rightgov_lsales lsales i.cycle ///
	if media_color=="right" & (type==1|type==2) & totspend_con>0, cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local cycle_fe "X"
	estadd local weighted ""
	
	eststo: reg spending_share_con rightgov_ind* ind2 ind3 ind4 ind5 ind6 i.cycle ///
	[aw=totspend_con] if media_color=="right" & (type==1|type==2) & totspend_con>0, cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local cycle_fe "X"
	estadd local weighted "X"
	
	eststo: reg spending_share_con rightgov_lemp lemp i.cycle ///
	[aw=totspend_con] if media_color=="right" & (type==1|type==2) & totspend_con>0, cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local cycle_fe "X"
	estadd local weighted "X"
	
	eststo: reg spending_share_con rightgov_lsales lsales i.cycle ///
	[aw=totspend_con] if media_color=="right" & (type==1|type==2) & totspend_con>0, cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local cycle_fe "X"
	estadd local weighted "X"	
}
esttab using "output/tableA9.tex", se star(* 0.10 ** 0.05 *** 0.01) label ///
		drop(*cycle) scalars("adv_fe Advertiser FE" "cycle_fe Cycle FE" "weighted Weighted") replace



