* Get ready
clear all
pause on
set more off

*******************
*** START *********
*******************


use "temp/aux3_largest_do_vege_print.dta", clear



* Restrict the sample to relevant printed media
keep if year<=2012&year>=2010

* Coloring newspapers
gen media_color="independent"
do coloring_metropol


* Preparation for the regressions
do regression_structure_metropol



***************************
*** Run the regressions ***
***************************


*** Table 4: Ownership change and advertising in Metropol


* Right government dummy
gen rightgov = tq > 205
keep if inrange(tq, 202, 209)


* Spending shares
egen spending_all=sum(spending), by(tax_idadvertiser /*year month*/ tq)
gen spending_share=.
replace spending_share=spending/spending_all if spending_all!=0 

egen totspend=sum(spending), by (tax_idadvertiser)
gen spending_norm=spending_all/totspend


* Surface shares
egen surface_all=sum(surface), by(tax_idadvertiser /*year month*/ tq)
gen surface_share=.
replace surface_share=surface/surface_all if surface_all!=0 


* Ownership dummies
gen foreign=0
replace foreign=1 if type==2
gen stateowned=0
replace stateowned=1 if type==3
gen muniowned=0
replace muniowned=1 if type==4


* Government agency and localgov type dummies
gen govt_agency = 0
gen gov_admin = 0
gen gov_pub = 0
gen localgov = 0
gen pol_party = 0
replace govt_agency = 1 if type==5
replace gov_admin = ministry + other_govt if type==5
replace gov_pub = education + health + culture if type==5
replace localgov = 1 if type==6
replace pol_party = 1 if type==7

* Right government x ownership dummies
gen rightgov_stateowned=rightgov*stateowned
gen rightgov_muniownedowned=rightgov*muniowned
gen rightgov_gov=rightgov*govt_agency
gen rightgov_loc=rightgov*localgov
gen rightgov_for=rightgov*foreign
gen rightgov_gov_admin = rightgov*gov_admin
gen rightgov_gov_pub = rightgov*gov_pub


* Time dummies
tab tq, gen(dtime)
*drop dtime4


* Event study regressions
foreach X of varlist stateowned gov_admin gov_pub{
	foreach v of numlist 1/8 {		
		gen `X'_dtime`v'=dtime`v'*`X'
	}
}
drop *dtime4*

* Labels for the regression output	
lab var spending_share "R/All"
lab var stateowned  "State-owned"
lab var stateowned_dtime1 "State-owned $\times$ pre-acquisition 4"
lab var stateowned_dtime2 "State-owned $\times$ pre-acquisition 3"
lab var stateowned_dtime3 "State-owned $\times$ pre-acquisition 2"
lab var stateowned_dtime5 "State-owned $\times$ post-acquisition 0"
lab var stateowned_dtime6 "State-owned $\times$ post-acquisition 1"
lab var stateowned_dtime7 "State-owned $\times$ post-acquisition 2"
lab var stateowned_dtime8 "State-owned $\times$ post-acquisition 3"


eststo clear
quietly{				

	eststo: reg spending_share stateowned* dtime* ///
	if media_color=="right"&(type==1|type==2|type==3)&totspend>0, cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local month_fe "X"
	estadd local weighted ""
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"

	xtset tax_idadvertiser
	eststo: xtreg spending_share stateowned_dtime* dtime* ///
	if media_color=="right"&(type==1|type==2|type==3)&totspend>0, fe cluster(tax_idadvertiser)
	estadd local adv_fe "X"
	estadd local month_fe "X"
	estadd local weighted ""
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"

	eststo: reg spending_share stateowned* dtime* ///
	[aw=totspend] if media_color=="right"&(type==1|type==2|type==3), cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local month_fe "X"
	estadd local weighted "X"
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"

	xtset tax_idadvertiser
	eststo: xtreg spending_share stateowned_dtime* dtime* ///
	[aw=totspend] if media_color=="right"&(type==1|type==2|type==3), fe cluster(tax_idadvertiser)
	estadd local adv_fe "X"
	estadd local month_fe "X"
	estadd local weighted "X"		
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"

}
esttab using "output/tableA3.tex", se star(* 0.10 ** 0.05 *** 0.01) label drop(dtime* _cons stateowned) replace ///
		scalars("adv_fe Advertiser FE" "month_fe Quarter FE" "weighted Weighted" )
		*scalars("adv_fe Advertiser FE" "month_fe Quarter FE" "weighted Weighted" "n_state State" "n_muni Muni" "n_gov_admin Gov admin" "n_gov_pub Gov pub" "n_localgov Localgov" "n_pol_party Pol party" "n_priv Private" "n_firms Firms")

		
		
		

	
		

