****** Origo regression ***********
clear all
pause on
set more off


*******************
*** START *********
*******************


use "temp/aux3_largest_do_vege_online.dta", clear

replace media="index" if strpos(media,"CEMP")
replace media="origo" if strpos(media,"ORIGO")
replace media="24.hu" if strpos(media,"CENTRAL MÉDIACSOPORT")
replace media="hvg" if strpos(media,"HVG")
replace media="ringier" if strpos(media,"RINGIER")|strpos(media,"AXEL SPRINGER")

keep if media=="index" | media=="origo" /*| media=="24.hu" */

gen media_color = "independent"
replace media_color="right" if media=="origo"


keep if year>=2013

do regression_structure_online
gen period2 = 0
gen period3 = 0
replace period2 = 1 if tq>tq(2014q2)&tq<tq(2016q1)
replace period3 = 1 if tq>=tq(2016q1)

egen time = group(tq)

egen spending_all=sum(spending), by(tax_idadvertiser tq)
gen spending_share=.
replace spending_share=spending/spending_all if spending_all!=0 

egen totspend=sum(spending), by (tax_idadvertiser)
gen spending_norm=spending_all/totspend
egen full_spending=sum(spending), by(type)


* Surface shares
egen surface_all=sum(surface), by(tax_idadvertiser tq)
gen surface_share=.
replace surface_share=surface/surface_all if surface_all!=0 

egen spending_share_av = mean(spending_share), by(media_color type time)
egen spending_sum = sum(spending), by(media_color type time)


* Ownership dummies
gen foreign=0
replace foreign=1 if type==2
gen stateowned=0
replace stateowned=1 if type==3
gen muniowned=0
replace muniowned=1 if type==4


* Government agency and localgov type dummies
gen govt_agency = 0
gen gov_admin = 0
gen gov_pub = 0
gen localgov = 0
gen pol_party = 0
replace govt_agency = 1 if type==5
replace gov_admin = ministry + other_govt if type==5
replace gov_pub = education + health + culture if type==5
replace localgov = 1 if type==6
replace pol_party = 1 if type==7


gen stateowned_p2 = stateowned*period2
gen stateowned_p3 = stateowned*period3
gen gov_admin_p2 = gov_admin*period2
gen gov_admin_p3 = gov_admin*period3
gen gov_pub_p2 = gov_pub*period2
gen gov_pub_p3 = gov_pub*period3

tab tq, gen(dtime)
drop dtime1


lab var spending_share "O/(O+I)"
lab var stateowned "State-owned"
lab var stateowned_p2 "State-owned $\times$ new editor"
lab var stateowned_p3 "State-owned $\times$ new owner"
lab var gov_admin "Govt. agency (admin)"
lab var gov_admin_p2 "Govt. agency (admin) $\times$ new editor"
lab var gov_admin_p3 "Govt. agency (admin) $\times$ new owner"
lab var gov_pub  "Govt. agency (public good)"
lab var gov_pub_p2  "Govt. agency (public good) $\times$ new editor"
lab var gov_pub_p3  "Govt. agency (public good) $\times$ new owner"


eststo clear
quietly{

	eststo: reg spending_share stateowned_p2 stateowned_p3 gov_admin_p2 gov_admin_p3 gov_pub_p2 gov_pub_p3 stateowned gov_admin gov_pub dtime* ///
	if media_color=="right"&(type==1|type==2|type==3|type==5)&totspend>0, cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local month_fe "X"
	estadd local weighted ""
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"

	xtset tax_idadvertiser
	eststo: xtreg spending_share stateowned_p2 stateowned_p3 gov_admin_p2 gov_admin_p3 gov_pub_p2 gov_pub_p3 dtime* ///
	if media_color=="right"&(type==1|type==2|type==3|type==5)&totspend>0, fe cluster(tax_idadvertiser)
	estadd local adv_fe "X"
	estadd local month_fe "X"
	estadd local weighted ""
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"

	eststo: reg spending_share stateowned_p2 stateowned_p3 gov_admin_p2 gov_admin_p3 gov_pub_p2 gov_pub_p3 stateowned gov_admin gov_pub dtime* ///
	[aw=totspend] if media_color=="right"&(type==1|type==2|type==3|type==5), cluster(tax_idadvertiser) 
	estadd local adv_fe ""
	estadd local month_fe "X"
	estadd local weighted "X"
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"

	xtset tax_idadvertiser
	eststo: xtreg spending_share stateowned_p2 stateowned_p3 gov_admin_p2 gov_admin_p3 gov_pub_p2 gov_pub_p3  dtime* ///
	[aw=totspend] if media_color=="right"&(type==1|type==2|type==3|type==5), fe cluster(tax_idadvertiser)
	estadd local adv_fe "X"
	estadd local month_fe "X"
	estadd local weighted "X"
	distinct tax_idadvertiser if e(sample) & stateowned
	estadd local n_state "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & muniowned
	estadd local n_muni "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_admin
	estadd local n_gov_admin "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & gov_pub
	estadd local n_gov_pub "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & localgov
	estadd local n_localgov "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & pol_party
	estadd local n_pol_party "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) & !stateowned & !muniowned & !gov_admin & !gov_pub & !localgov & !pol_party
	estadd local n_priv "`r(ndistinct)'"
	distinct tax_idadvertiser if e(sample) 
	estadd local n_firms "`r(ndistinct)'"
}
esttab using "output/tableA4.tex" ,se star(* 0.10 ** 0.05 *** 0.01) label drop(dtime* _cons) replace ///
		scalars("adv_fe Advertiser FE" "month_fe Quarter FE" "weighted Weighted") 
		*scalars("adv_fe Advertiser FE" "month_fe Quarter FE" "weighted Weighted" "n_state State" "n_muni Muni" "n_gov_admin Gov admin" "n_gov_pub Gov pub" "n_localgov Localgov" "n_pol_party Pol party" "n_priv Private" "n_firms Firms") 