clear all
pause on
set more off


*******************
*** START *********
*******************

import delimited "input/media_analysis/media_analysis_results.csv", encoding(UTF-8) clear

split date, p("_")
destring date1, gen(year)
destring date2, gen(month)
drop date*





*** FIND LAST time WHEN NOL EXISTS
*** Set start and and dates based on DATES and not TIME
drop if year < 2010 | year > 2016 | (year == 2016 & month > 10 )
*drop if year < 2010 | year > 2016 | (year == 2016 & month > 7 )
*drop if year < 2010
keep if inlist(page, "MNO", "NOL", "MH")




egen time=group(year month)
tab time, gen(dtime)
drop dtime55

order page year month time

egen media=group(page)
gen corr_share=any/all*100

gen mno = page == "MNO"
gen nol = page == "NOL"
gen mh  = page == "MH"

gen post = year > 2015 | (year == 2015 & month >= 3)
gen post_mno = post * mno
gen post_nol = post * nol


*label var corr_share "Share of corruption articles"
label var post_mno "Affected right-wing daily $\times$ post fallout"
label var post_nol "Left-wing daily $\times$ post fallout"
label var mno "Affected right-wing daily"
label var nol "Left-wing daily"
*/

eststo clear
quietly{
	eststo: reg corr_share post_mno post_nol mno nol dtime* if time >= 55, robust
	estadd local month_fe "X"
	sum year if e(sample)
	local first_date = "`r(min)'"
	local last_date = "`r(max)'"
	sum month if e(sample) & year == `first_date'
	local first_date = "`first_date' `r(min)'"
	estadd local firstobs "`first_date'"
	sum month if e(sample) & year == `last_date'
	local last_date = "`last_date' `r(max)'"
	estadd local lastobs "`last_date'"
	count if post == 0 & e(sample) & mno
	estadd local n_pre `r(N)'
	count if post == 1 & e(sample) & mno
	estadd local n_post `r(N)'
	
	eststo: reg corr_share post_mno mno dtime* if time >= 37 & (page=="MNO" | page=="NOL"), robust
	estadd local month_fe "X"
	sum year if e(sample)
	local first_date = "`r(min)'"
	local last_date = "`r(max)'"
	sum month if e(sample) & year == `first_date'
	local first_date = "`first_date' `r(min)'"
	estadd local firstobs "`first_date'"
	sum month if e(sample) & year == `last_date'
	local last_date = "`last_date' `r(max)'"
	estadd local lastobs "`last_date'"
	count if post == 0 & e(sample) & mno
	estadd local n_pre `r(N)'
	count if post == 1 & e(sample) & mno
	estadd local n_post `r(N)'

}
esttab using "output/tableA5.tex", se star(* 0.10 ** 0.05 *** 0.01) label ///
		drop(dtime* _cons) scalars("month_fe Month FE" /*"firstobs First date" "lastobs Last date" "n_pre Pre" "n_post Post"*/) replace









