clear all
pause on
set more off


*******************
*** START *********
*******************

import delimited "input/media_analysis/media_analysis_results.csv", encoding(UTF-8) clear

split date, p("_")
destring date1, gen(year)
destring date2, gen(month)
drop date*

keep if inlist(page, "INDEX", "ORIGO")
*drop if year < 2012 | (year == 2018 & month >= 8)
*drop if year < 2013 | year > 2016 | (year == 2016 & month == 12)
drop if year < 2012 | year > 2016 | (year == 2016 & month > 10 )



egen time=group(year month)
tab time, gen(dtime)
drop dtime1

order page year month time

gen corr_share=any/all*100


gen origo = (page=="ORIGO")
gen period2 = (time>=31&time<49)
gen period3 = (time>=49)
gen origo_p2 = origo*period2
gen origo_p3 = origo*period3

*label var corr_share "Share of corruption articles"
label var origo "Origo"
label var origo_p2 "Origo $\times$ new editor"
label var origo_p3 "Origo $\times$ new owner"

eststo clear
quietly{
	eststo: reg corr_share origo_p2 origo_p3 origo period2 period3 if time >= 13, robust
	estadd local period_fe "X"
	estadd local month_fe ""
	sum year if e(sample)
	local first_date = "`r(min)'"
	local last_date = "`r(max)'"
	sum month if e(sample) & year == `first_date'
	local first_date = "`first_date' `r(min)'"
	estadd local firstobs "`first_date'"
	sum month if e(sample) & year == `last_date'
	local last_date = "`last_date' `r(max)'"
	estadd local lastobs "`last_date'"
	count if period2 == 0 & period3 == 0 & e(sample) & origo
	estadd local n_pre `r(N)'
	count if period2 == 1 & e(sample) & origo
	estadd local n_p2 `r(N)'
	count if period3 == 1 & e(sample) & origo
	estadd local n_p3 `r(N)'

	eststo: reg corr_share origo_p2 origo_p3 origo dtime*  if time >= 13, robust
	estadd local period_fe ""
	estadd local month_fe "X"
	sum year if e(sample)
	local first_date = "`r(min)'"
	local last_date = "`r(max)'"
	sum month if e(sample) & year == `first_date'
	local first_date = "`first_date' `r(min)'"
	estadd local firstobs "`first_date'"
	sum month if e(sample) & year == `last_date'
	local last_date = "`last_date' `r(max)'"
	estadd local lastobs "`last_date'"
	count if period2 == 0 & period3 == 0 & e(sample) & origo
	estadd local n_pre `r(N)'
	count if period2 == 1 & e(sample) & origo
	estadd local n_p2 `r(N)'
	count if period3 == 1 & e(sample) & origo
	estadd local n_p3 `r(N)'

}
esttab using "output/tableA6.tex", se star(* 0.10 ** 0.05 *** 0.01) label ///
		drop(period* dtime* _cons) scalars("period_fe Period FE" "month_fe Month FE" "firstobs First date" "lastobs Last date" "n_pre Pre" "n_p2 Post 2" "n_p3 Post 3") replace

		


