clear
timer clear
timer on 1
global N_reps = 1000


use "input/TARKI/omnibus.dta", clear

drop if hullam == 201304 | hullam == 201305 | hullam == 201306 | hullam == 201310

append using "input/TARKI/TARKI2013_Szeidl.dta" 
replace teltip = 1 if teltip==9
replace megye = 1 if megye==99

gen age = ev-szulev
gen age_sq = age^2

gen right = 0
replace right = 1 if pol05==32

gen left = 0
replace left =1 if pol05==31|pol05==41|pol05==42|pol05==43

gen indep = 1
replace indep = 0 if left==1|right==1

gen vote = "indep"
replace vote = "right" if right==1
replace vote = "left" if left==1

gen index = 0 if od105h!=. & od105h!=.b
replace index = 1 if od105h==1

gen origo = 0 if od105i!=. & od105i!=.b
replace origo = 1 if od105i==1

gen mno = 0 if usa18c!=. & usa18c!=.b
replace mno = 1 if usa18c==1 

gen nol = 0 if usa18e!=. & usa18e!=.b
replace nol = 1 if usa18e==1 

gen isk4 = 1 if iskola==2|iskola==1 
replace isk4 = 2 if iskola==3
replace isk4 = 3 if iskola==4|iskola==5|iskola==6|iskola==7
replace isk4 = 4 if iskola==8|iskola==9 

tab index origo if (hullam == 201304 | hullam == 201305 | hullam == 201306 | hullam == 201310), matcell(crosstable)
scalar overlap_online = crosstable[2,2]/(crosstable[1,2]+crosstable[2,1]+crosstable[2,2])
tab nol mno if (hullam == 201304 | hullam == 201305 | hullam == 201306 | hullam == 201310), matcell(crosstable)
scalar overlap_print = crosstable[2,2]/(crosstable[1,2]+crosstable[2,1]+crosstable[2,2])
scalar list overlap_online
scalar list overlap_print

matrix Online = ( 0,0\ 0,0)
mat colnames Online = Index Origo
mat rownames Online = Right Left
local i = 1
foreach v in right left { 
reg `v' if index==1&(hullam == 201304 | hullam == 201305 | hullam == 201306 | hullam == 201310)
matrix Online[`i',1] = _b[_cons]
estimates store eq1
reg `v' if origo==1&(hullam == 201304 | hullam == 201305 | hullam == 201306 | hullam == 201310)
matrix Online[`i',2] = _b[_cons]
estimates store eq2
suest eq1 eq2
lincom [eq1_mean]_cons - [eq2_mean]_cons
local i = `i'+1
}

matrix Print = ( 0,0\ 0,0)
mat colnames Print = "Nepszabadsag" "Magyar Nemzet"
mat rownames Print = Right Left
local i = 1
foreach v in right left { 
reg `v' if nol==1&(hullam == 201304 | hullam == 201305 | hullam == 201306 | hullam == 201310)
matrix Print[`i',1] = _b[_cons]
estimates store eq1
reg `v' if mno==1&(hullam == 201304 | hullam == 201305 | hullam == 201306 | hullam == 201310)
matrix Print[`i',2] = _b[_cons]
estimates store eq2
suest eq1 eq2
lincom [eq1_mean]_cons - [eq2_mean]_cons
local i = `i'+1
}

matrix list Online
matrix list Print

putexcel set "output/numbers_in_text_readers.xlsx", sheet("Online") replace
putexcel A1=matrix(Online)

putexcel set "output/numbers_in_text_readers.xlsx", sheet("Print") modify
putexcel A1=matrix(Print)

*scalar column = 3
gen nap = 1
gen date = mdy(ho,nap,ev)
format date %td
gen period2 = (date>=td(01jun2014)&date<td(01jan2016))
gen period3 = (date>=td(01jan2016))
gen period4 = (date>=td(01feb2015))


eststo clear


*** Column 1: Origo vs Index
preserve
	probit origo i.isk4 i.teltip i.megye age age_sq i.neme
	predict origo_pred
	replace origo_pred = origo_pred * 100
	egen prob_o = mean(origo)
	gen weight_o = origo_pred/prob_o
	gen right_w1 = right*weight_o

	probit index i.isk4 i.teltip i.megye age age_sq i.neme
	predict index_pred
	replace index_pred = index_pred * 100
	egen prob_i = mean(index)
	gen weight_i = index_pred/prob_i
	gen right_w2 = right*weight_i
	gen id = _n
	reshape long right_w, i(id) j(sample)

	gen origo_period2 = (sample==1)*period2
	gen origo_period3 = (sample==1)*period3
	gen o_sample = (sample==1)
	reg right_w o_sample origo_period2 origo_period3 period2 period3
	local N = e(N)
	matrix coeff =(_b[o_sample], _b[origo_period2], _b[origo_period3])

	matrix list coeff
restore

capture program drop myboot
program define myboot, rclass
	preserve 
		bsample
		probit origo i.isk4 i.teltip i.megye age age_sq i.neme
		predict origo_pred
		replace origo_pred = origo_pred * 100
		egen prob_o = mean(origo)
		gen weight_o = origo_pred/prob_o
		gen right_w1 = right*weight_o

		probit index i.isk4 i.teltip i.megye age age_sq i.neme
		predict index_pred
		replace index_pred = index_pred * 100
		egen prob_i = mean(index)
		gen weight_i = index_pred/prob_i
		gen right_w2 = right*weight_i

		gen id = _n
		reshape long right_w, i(id) j(sample)

		gen origo_period2 = (sample==1)*period2
		gen origo_period3 = (sample==1)*period3
		gen o_sample = (sample==1)
		reg right_w o_sample origo_period2 origo_period3 i.date
		return scalar coeff_1 = _b[o_sample]
		return scalar coeff_2 = _b[origo_period2]
		return scalar coeff_3 = _b[origo_period3]
	restore
end
		
preserve
	simulate coeff_1=r(coeff_1) coeff_2=r(coeff_2) coeff_3=r(coeff_3), reps(${N_reps}) seed(12345): myboot
	eststo: bstat, stat(coeff)
	estadd local N_obs `N'
restore


*** Column 2: Magyar Nemzet vs Népszabadság
preserve
	probit mno i.isk4 i.teltip i.megye age age_sq i.neme
	predict mno_pred
	replace mno_pred = mno_pred * 100
	egen prob_mno = mean(mno)
	gen weight_mno = mno_pred/prob_mno
	gen right_w1 = right*weight_mno

	probit nol i.isk4 i.teltip i.megye age age_sq i.neme
	predict nol_pred
	replace nol_pred = nol_pred * 100
	egen prob_nol = mean(nol)
	gen weight_nol = nol_pred/prob_nol
	gen right_w2 = right*weight_nol
	gen id = _n
	reshape long right_w, i(id) j(sample)

	gen mno_period4 = (sample==1)*period4
	gen mno_sample = (sample==1)
	reg right_w mno_sample mno_period4 i.date
	local N = e(N)
	matrix coeff =(_b[mno_sample], _b[mno_period4])

	matrix list coeff
restore

capture program drop myboot
program define myboot, rclass
	preserve 
		bsample
		probit mno i.isk4 i.teltip i.megye age age_sq i.neme
		predict mno_pred
		replace mno_pred = mno_pred * 100
		egen prob_mno = mean(mno)
		gen weight_mno = mno_pred/prob_mno
		gen right_w1 = right*weight_mno

		probit nol i.isk4 i.teltip i.megye age age_sq i.neme
		predict nol_pred
		replace nol_pred = nol_pred * 100
		egen prob_nol = mean(nol)
		gen weight_nol = nol_pred/prob_nol
		gen right_w2 = right*weight_nol

		gen id = _n
		reshape long right_w, i(id) j(sample)

		gen mno_period4 = (sample==1)*period4
		gen mno_sample = (sample==1)
		reg right_w mno_sample mno_period4 i.date
		return scalar coeff_1 = _b[mno_sample]
		return scalar coeff_2 = _b[mno_period4]
	restore
end

preserve
	simulate coeff_1=r(coeff_1) coeff_2=r(coeff_2), reps(${N_reps}) seed(12345): myboot
	eststo: bstat, stat(coeff)
	estadd local N_obs `N'
restore


*** Column 3: Magyar Nemzet vs Index
preserve
	probit mno i.isk4 i.teltip i.megye age age_sq i.neme
	predict mno_pred
	replace mno_pred = mno_pred * 100	
	egen prob_mno = mean(mno)
	gen weight_mno = mno_pred/prob_mno
	gen right_w1 = right*weight_mno

	probit index i.isk4 i.teltip i.megye age age_sq i.neme
	predict index_pred
	replace index_pred = index_pred * 100
	egen prob_i = mean(index)
	gen weight_i = index_pred/prob_i
	gen right_w2 = right*weight_i
	gen id = _n
	reshape long right_w, i(id) j(sample)

	gen mno_period4 = (sample==1)*period4
	gen mno_sample = (sample==1)
	reg right_w mno_sample mno_period4 i.date
	local N = e(N)
	matrix coeff =(_b[mno_sample], _b[mno_period4])

	matrix list coeff
restore

capture program drop myboot
program define myboot, rclass
	preserve 
		bsample
		probit mno i.isk4 i.teltip i.megye age age_sq i.neme
		predict mno_pred
		replace mno_pred = mno_pred * 100
		egen prob_mno = mean(mno)
		gen weight_mno = mno_pred/prob_mno
		gen right_w1 = right*weight_mno

		probit index i.isk4 i.teltip i.megye age age_sq i.neme
		predict index_pred
		replace index_pred = index_pred * 100
		egen prob_i = mean(index)
		gen weight_i = index_pred/prob_i
		gen right_w2 = right*weight_i

		gen id = _n
		reshape long right_w, i(id) j(sample)

		gen mno_period4 = (sample==1)*period4
		gen mno_sample = (sample==1)
		reg right_w mno_sample mno_period4 i.date
		return scalar coeff_1 = _b[mno_sample]
		return scalar coeff_2 = _b[mno_period4]
	restore
end

preserve	
	simulate coeff_1=r(coeff_1) coeff_2=r(coeff_2), reps(${N_reps}) seed(12345): myboot
	eststo: bstat, stat(coeff)
	estadd local N_obs `N'
restore


*** Export results	
esttab using "output/tableA8.tex" ,se star(* 0.10 ** 0.05 *** 0.01) label replace noobs scalars("N_obs N") 

timer off 1 
timer list
